@@ -12,7 +12,7 @@
 #'   \code{envisioned} (inspired by the project \code{Envisioned CSS}
 #'   \url{https://github.com/nogginfuel/envisioned-css} but essentially just
 #'   sets the font family to \code{Roboto Condensed}, and changed the
-#'   background/foregroudn colors).
+#'   background/foreground colors).
 #' @param margin_references Whether to place citations in margin notes.
 #' @rdname tufte_handout
 #' @export
@@ -176,7 +176,7 @@ tufte_html_dependency = function(features, variant) {
 # we assume one footnote only contains one paragraph here, although it is
 # possible to write multiple paragraphs in a footnote with Pandoc's Markdown
 parse_footnotes = function(x, fn_label = 'fn') {
-  i = which(x == '<div class="footnotes">')
+  i = grep('^<div class="footnotes[^"]*"[^>]*>', x)
   if (length(i) == 0) return(list(items = character(), range = integer()))
   j = which(x == '</div>')
   j = min(j[j > i])
@@ -194,7 +194,7 @@ parse_footnotes = function(x, fn_label = 'fn') {
 
 # move reference items from the bottom to the margin (as margin notes)
 margin_references = function(x) {
-  i = grep('^<div id="refs" class="references[^"]*">$', x)
+  i = grep('^<div id="refs" class="references[^"]*"[^>]*>$', x)
   if (length(i) != 1) return(x)
   # link-citations: no
   if (length(grep('<a href="#ref-[^"]+"[^>]*>([^<]+)</a>', x)) == 0) return(x)
@@ -210,12 +210,7 @@ margin_references = function(x) {
   # <a href="#ref-R-rmarkdown" role="doc-biblioref">Allaire et al.</a> (<a href="#ref-R-rmarkdown" role="doc-biblioref">2020</a>)</span>
   # we need to merge the two links
   r2 = '(<a href="#ref-[^"]+"[^>]*>)([^<]+)</a>([^<]*)\\1([^<]+)</a>([^<]*)'
-  i2 = grep(r2, x)
-  if (length(i2) != 0L) {
-    m = regmatches(x[i2], regexec(r2, x[i2]))
-    m = vapply(m, function(x) paste(c(x[-1], "</a>"), collapse = ""), character(1))
-    for (j in seq_along(i2)) x[i2[j]] = gsub(r2, m[j], x[i2[j]])
-  }
+  x = gsub(r2, "\\1\\2\\3\\4\\5</a>", x)
   ids = gsub(r, '\\1', x[k])
   ids = sprintf('<a href="#%s"[^>]*>([^<]+)</a>', ids)
   ref = gsub('^<p>|</p>$', '', x[k + 1])
